@@ -265,6 +265,12 @@ class ColorInput(TextInput):  # lgtm [py/missing-call-to-init]
         self.change()
 
     def set_value(self, color: Optional[Union[str, Tuple3IntType]]) -> None:
+        """
+        Set the color value.
+
+        :param color: A string if the type is HEX, or a (r, g, b) tuple if RGB
+        :return: None
+        """
         if color is None:
             color = ''
         format_color = ''
@@ -287,7 +293,7 @@ class ColorInput(TextInput):  # lgtm [py/missing-call-to-init]
 
         elif self._color_type == COLORINPUT_TYPE_HEX:
             text = str(color).strip()
-            if text == '':
+            if text == '' or text == '#':
                 format_color = '#'
             else:
                 # Remove all invalid chars
@@ -307,12 +313,18 @@ class ColorInput(TextInput):  # lgtm [py/missing-call-to-init]
                 if count_hash == 0:
                     text = '#' + text
                 assert len(text) == 7, \
-                    'invalid color, only formats "#RRGGBB" and "RRGGBB" are allowed'
+                    'invalid color, only formats "#RRGGBB" or "RRGGBB" are allowed'
                 format_color = text
 
         super(ColorInput, self).set_value(format_color)
         self._format_hex()
 
+    def value_changed(self) -> bool:
+        default = self._default_value
+        if self._color_type == COLORINPUT_TYPE_HEX and '#' not in default:
+            default = '#' + default
+        return self.get_value(as_string=True) != default
+
     def get_value(self, as_string: bool = False) -> Union[str, Tuple3IntType]:
         """
         Return the color value as a tuple or red blue and green channels.
@@ -431,9 +443,9 @@ class ColorInput(TextInput):  # lgtm [py/missing-call-to-init]
                 # User writes
                 if event.type == pygame.KEYDOWN and self._keyboard_enabled:
 
-                    # Check if any key is pressed, if True the event is invalid
+                    # Check if any key is pressed
                     if not check_key_pressed_valid(event):
-                        return True
+                        continue
 
                     if disable_remove_separator and len(input_str) > 0 and \
                             len(input_str) > cursor_pos and (
@@ -511,9 +523,9 @@ class ColorInput(TextInput):  # lgtm [py/missing-call-to-init]
 
                 # User writes
                 if event.type == pygame.KEYDOWN and self._keyboard_enabled:
-                    # Check if any key is pressed, if True the event is invalid
+                    # Check if any key is pressed
                     if not check_key_pressed_valid(event):
-                        return True
+                        continue
 
                     # Backspace button, delete text from right
                     if event.key == pygame.K_BACKSPACE:
