@@ -53,7 +53,7 @@ import pygame_menu.controls as ctrl
 from pygame_menu.locals import FINGERUP
 from pygame_menu.utils import check_key_pressed_valid, assert_color, assert_vector, \
     make_surface, get_finger_pos
-from pygame_menu.widgets.core import Widget
+from pygame_menu.widgets.core.widget import Widget
 
 from pygame_menu._types import Tuple, Union, List, Any, Optional, CallbackType, \
     Literal, ColorType, ColorInputType, Tuple2IntType, Tuple3IntType, EventVectorType, \
@@ -86,7 +86,7 @@ def check_selector_items(items: Union[Tuple, List]) -> None:
 class Selector(Widget):
     """
     Selector widget: several items and two functions that are executed when changing
-    the selector (left/right) and pressing return button on the selected item.
+    the selector (left/right) and pressing return key on the selected item.
 
     The items of the selector are like:
 
@@ -374,6 +374,9 @@ class Selector(Widget):
         """
         return self._items[self._index], self._index
 
+    def value_changed(self) -> bool:
+        return self._index != self._default_value
+
     def _left(self) -> None:
         """
         Move selector to left.
@@ -431,6 +434,7 @@ class Selector(Widget):
                 'item index must be greater than zero and lower than the number ' \
                 'of items on the selector'
             self._index = item
+        self._render()
 
     def update_items(self, items: Union[List[Tuple[Any, ...]], List[str]]) -> None:
         """
