@@ -39,7 +39,7 @@ import pygame_menu.controls as ctrl
 from pygame_menu.locals import FINGERDOWN, FINGERUP, INPUT_INT, INPUT_FLOAT, INPUT_TEXT
 from pygame_menu.utils import check_key_pressed_valid, make_surface, assert_color, \
     get_finger_pos, warn, assert_vector
-from pygame_menu.widgets.core import Widget
+from pygame_menu.widgets.core.widget import Widget, WidgetTransformationNotImplemented
 
 from pygame_menu._types import Optional, Any, CallbackType, Tuple, List, ColorType, \
     NumberType, Tuple2IntType, Dict, Tuple2NumberType, NumberInstance, ColorInputType, \
@@ -57,7 +57,12 @@ except (ModuleNotFoundError, ImportError):
         """
         Pyperclip exception thrown by pyperclip.
         """
-        pass
+
+CTRL_KMOD = (
+    pygame.KMOD_CTRL, pygame.KMOD_CTRL | pygame.KMOD_CAPS,
+    pygame.KMOD_LCTRL, pygame.KMOD_LCTRL | pygame.KMOD_CAPS,
+    pygame.KMOD_RCTRL, pygame.KMOD_RCTRL | pygame.KMOD_CAPS
+)
 
 
 # noinspection PyMissingOrEmptyDocstring
@@ -222,17 +227,24 @@ class TextInput(Widget):
         assert isinstance(textinput_id, str)
         assert isinstance(valid_chars, (type(None), list))
 
-        assert history >= 0, 'history must be equal or greater than zero'
-        assert maxchar >= 0, 'maxchar must be equal or greater than zero'
-        assert maxwidth >= 0, 'maxwidth must be equal or greater than zero'
-        assert len(password_char) == 1, 'password char must be a character'
+        assert history >= 0, \
+            'history must be equal or greater than zero'
+        assert maxchar >= 0, \
+            'maxchar must be equal or greater than zero'
+        assert maxwidth >= 0, \
+            'maxwidth must be equal or greater than zero'
+        assert len(password_char) == 1, \
+            'password char must be a character'
         assert input_underline_len >= 0, \
             'input underline length must be equal or greater than zero'
         assert cursor_switch_ms > 0, \
             'cursor switch in milliseconds must be greater than zero'
-        assert repeat_keys_initial_ms > 0, 'ms cannot be lower or equal than zero'
-        assert repeat_keys_interval_ms > 0, 'ms cannot be lower or equal than zero'
-        assert repeat_mouse_interval_ms > 0, 'ms cannot be lower or equal than zero'
+        assert repeat_keys_initial_ms > 0, \
+            'ms cannot be lower or equal than zero'
+        assert repeat_keys_interval_ms > 0, \
+            'ms cannot be lower or equal than zero'
+        assert repeat_mouse_interval_ms > 0, \
+            'ms cannot be lower or equal than zero'
 
         cursor_color = assert_color(cursor_color)
         cursor_selection_color = assert_color(cursor_selection_color)
@@ -263,6 +275,7 @@ class TextInput(Widget):
         self._ignore_keys = (  # Ignore keys on keyrepeat event
             ctrl.KEY_MOVE_DOWN,
             ctrl.KEY_MOVE_UP,
+            ctrl.KEY_TAB,
             pygame.K_CAPSLOCK,
             pygame.K_END,
             pygame.K_ESCAPE,
@@ -272,8 +285,7 @@ class TextInput(Widget):
             pygame.K_NUMLOCK,
             pygame.K_RCTRL,
             pygame.K_RETURN,
-            pygame.K_RSHIFT,
-            pygame.K_TAB
+            pygame.K_RSHIFT
         )
 
         # Vars to make keydown repeat after user pressed a key for some time:
@@ -419,20 +431,20 @@ class TextInput(Widget):
                 value = 0
         return value
 
-    def rotate(self, *args, **kwargs) -> 'TextInput':
-        return self
-
     def scale(self, *args, **kwargs) -> 'TextInput':
-        return self
-
-    def set_max_height(self, *args, **kwargs) -> 'TextInput':
-        return self
-
-    def set_max_width(self, *args, **kwargs) -> 'TextInput':
-        return self
+        raise WidgetTransformationNotImplemented()
 
     def resize(self, *args, **kwargs) -> 'TextInput':
-        return self
+        raise WidgetTransformationNotImplemented()
+
+    def set_max_width(self, *args, **kwargs) -> 'TextInput':
+        raise WidgetTransformationNotImplemented()
+
+    def set_max_height(self, *args, **kwargs) -> 'TextInput':
+        raise WidgetTransformationNotImplemented()
+
+    def rotate(self, *args, **kwargs) -> 'TextInput':
+        raise WidgetTransformationNotImplemented()
 
     def flip(self, x: bool, y: bool) -> 'TextInput':  # Actually flip on x axis is disabled
         super(TextInput, self).flip(False, y)
@@ -1127,7 +1139,6 @@ class TextInput(Widget):
         """
         if string == '':  # Empty is valid
             return True
-
         if self._input_type == INPUT_TEXT:
             return True
 
@@ -1139,7 +1150,6 @@ class TextInput(Widget):
 
         if string == '-':
             return True
-
         if conv is None:
             return False
 
@@ -1200,7 +1210,7 @@ class TextInput(Widget):
             self._cursor_surface.fill(self._cursor_color)
         self._selection_active = False
         self.force_menu_surface_cache_update()
-        return removed
+        return True
 
     def _get_selected_text(self) -> str:
         """
@@ -1594,9 +1604,7 @@ class TextInput(Widget):
                     self._keyrepeat_counters[event.key] = [0, event.unicode]
 
                 # User press ctrl+something
-                if pygame.key.get_mods() in (pygame.KMOD_CTRL, pygame.KMOD_RCTRL,
-                                             pygame.KMOD_LCTRL):
-
+                if pygame.key.get_mods() in CTRL_KMOD:
                     # If test, disable CTRL
                     if 'test' in event.dict and event.dict['test']:
                         # noinspection PyArgumentList
@@ -1706,7 +1714,6 @@ class TextInput(Widget):
 
                 # Backspace button, delete text from right
                 if event.key == pygame.K_BACKSPACE:
-
                     # Play sound
                     if self._cursor_position == 0:
                         self._sound.play_event_error()
@@ -1726,7 +1733,6 @@ class TextInput(Widget):
 
                 # Delete button, delete text from left
                 elif event.key == pygame.K_DELETE:
-
                     # Play sound
                     if self._cursor_position == len(self._input_string):
                         self._sound.play_event_error()
@@ -1746,7 +1752,6 @@ class TextInput(Widget):
 
                 # Right arrow
                 elif event.key == pygame.K_RIGHT:
-
                     # Play sound
                     if self._cursor_position == len(self._input_string):
                         self._sound.play_event_error()
@@ -1775,7 +1780,6 @@ class TextInput(Widget):
 
                 # Left arrow
                 elif event.key == pygame.K_LEFT:
-
                     # Play sound
                     if self._cursor_position == 0:
                         self._sound.play_event_error()
@@ -1828,7 +1832,7 @@ class TextInput(Widget):
                     updated = True
 
                 # Tab
-                elif event.key == pygame.K_TAB:
+                elif event.key == ctrl.KEY_TAB:
                     for _ in range(self._tab_size):
                         self._push_key_input(' ')
                         updated = True
@@ -1869,6 +1873,7 @@ class TextInput(Widget):
                             'check if event has defined the proper unicode char'
                             ''.format(self.get_class_id(), event.unicode, event.key)
                         )
+                        break
 
                     # Error in char, not valid or string limit exceeds
                     if not self._push_key_input(event.unicode):
@@ -1938,16 +1943,10 @@ class TextInput(Widget):
                     0] = self._keyrepeat_initial_interval_ms - self._keyrepeat_interval_ms
 
                 event_key, event_unicode = key, self._keyrepeat_counters[key][1]
-                try:
-                    # noinspection PyArgumentList
-                    self._add_event(
-                        pygame.event.Event(pygame.KEYDOWN,
-                                           key=event_key,
-                                           unicode=event_unicode)
-                    )
-
-                # If the keys are too fast pygame can raise a Sound Exception
-                except pygame.error:
-                    pass
+                self._add_event(
+                    pygame.event.Event(pygame.KEYDOWN,
+                                       key=event_key,
+                                       unicode=event_unicode)
+                )
 
         return updated
